# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12proto/common.proto\"/\n\x0b\x41\x63knowledge\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')



_ACKNOWLEDGE = DESCRIPTOR.message_types_by_name['Acknowledge']
Acknowledge = _reflection.GeneratedProtocolMessageType('Acknowledge', (_message.Message,), {
  'DESCRIPTOR' : _ACKNOWLEDGE,
  '__module__' : 'proto.common_pb2'
  # @@protoc_insertion_point(class_scope:Acknowledge)
  })
_sym_db.RegisterMessage(Acknowledge)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACKNOWLEDGE._serialized_start=22
  _ACKNOWLEDGE._serialized_end=69
# @@protoc_insertion_point(module_scope)
