# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lmao_v2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rlmao_v2.proto\x12\x07lmao_v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\x83\x02\n\x07Project\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12\x12\n\ntotal_runs\x18\x04 \x01(\x05\x12\x16\n\x0etotal_servings\x18\t \x01(\x05\x12\x13\n\x0blog_metrics\x18\x05 \x03(\t\x12\x16\n\x0e\x63onfig_metrics\x18\x06 \x03(\t\x12\x17\n\x0fserving_metrics\x18\n \x03(\t\x12\x0c\n\x04tags\x18\x0b \x03(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\x03\x12\x12\n\nis_deleted\x18\x08 \x01(\x08\x12\x10\n\x08relic_id\x18\x0c \x01(\t\"*\n\x12InitProjectRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"e\n\x13InitProjectResponse\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08relic_id\x18\x03 \x01(\t\x12\x12\n\nrelic_name\x18\x04 \x01(\t\"X\n\x13ListProjectsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x1a\n\x12project_id_or_name\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\"O\n\x14ListProjectsResponse\x12\"\n\x08projects\x18\x01 \x03(\x0b\x32\x10.lmao_v2.Project\x12\x13\n\x0btotal_pages\x18\x02 \x01(\x05\"\xda\x01\n\x0c\x41gentDetails\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\'\n\x04type\x18\x02 \x01(\x0e\x32\x19.lmao_v2.AgentDetails.NBX\x12\x14\n\nnbx_job_id\x18\x65 \x01(\tH\x00\x12\x18\n\x0enbx_serving_id\x18\x66 \x01(\tH\x00\x12\x14\n\nnbx_run_id\x18g \x01(\tH\x01\x12\x16\n\x0cnbx_model_id\x18h \x01(\tH\x01\"\x1b\n\x03NBX\x12\x07\n\x03JOB\x10\x00\x12\x0b\n\x07SERVING\x10\x01\x42\x04\n\x02idB\n\n\x08instance\"/\n\x0b\x41\x63knowledge\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xb5\x02\n\x0cRecordColumn\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\nvalue_type\x18\x02 \x01(\x0e\x32\x1e.lmao_v2.RecordColumn.DataType\x12-\n\x04rows\x18\x03 \x03(\x0b\x32\x1f.lmao_v2.RecordColumn.RecordRow\x1a\x84\x01\n\tRecordRow\x12\t\n\x01x\x18\x01 \x01(\x03\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nfloat_data\x18\x64 \x01(\x02\x12\x14\n\x0cinteger_data\x18\x65 \x01(\x05\x12\x13\n\x0bstring_data\x18\x66 \x01(\t\".\n\x08\x44\x61taType\x12\t\n\x05\x46LOAT\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\n\n\x06STRING\x10\x02\"\xef\x01\n\x06Record\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\nvalue_type\x18\x02 \x01(\x0e\x32\x18.lmao_v2.Record.DataType\x12\x0c\n\x04step\x18\x03 \x01(\x03\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nfloat_data\x18\x64 \x03(\x02\x12\x14\n\x0cinteger_data\x18\x65 \x03(\x05\x12\x13\n\x0bstring_data\x18\x66 \x03(\t\".\n\x08\x44\x61taType\x12\t\n\x05\x46LOAT\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\n\n\x06STRING\x10\x02\"\xfd\x01\n\x06RunLog\x12\x14\n\x0cworkspace_id\x18\x06 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x12\n\nserving_id\x18\x07 \x01(\t\x12\x1d\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x0f.lmao_v2.Record\x12*\n\x0b\x63olumn_data\x18\x03 \x03(\x0b\x32\x15.lmao_v2.RecordColumn\x12)\n\x08log_type\x18\x04 \x01(\x0e\x32\x17.lmao_v2.RunLog.LogType\"(\n\x07LogType\x12\n\n\x06SYSTEM\x10\x00\x12\x07\n\x03NBX\x10\x01\x12\x08\n\x04USER\x10\x02\"\xdf\x02\n\x07Serving\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12\x12\n\nserving_id\x18\x04 \x01(\t\x12$\n\x05\x61gent\x18\x05 \x01(\x0b\x32\x15.lmao_v2.AgentDetails\x12\x12\n\ncreated_at\x18\x06 \x01(\x03\x12\x0f\n\x07updated\x18\x07 \x01(\x03\x12\x10\n\x08\x65nded_at\x18\x08 \x01(\x03\x12\x15\n\rsave_location\x18\t \x01(\t\x12\x0e\n\x06\x63onfig\x18\n \x01(\t\x12\'\n\x06status\x18\x0b \x01(\x0e\x32\x17.lmao_v2.Serving.Status\x12\x13\n\x0bupdate_keys\x18\x64 \x03(\t\">\n\x06Status\x12\x0b\n\x07NOT_SET\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\r\n\tCOMPLETED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\"^\n\x13ListServingsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\x08\"b\n\x14ListServingsResponse\x12\x13\n\x0bserving_ids\x18\x01 \x03(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x12\n\ncreated_at\x18\x03 \x03(\x03\x12\x13\n\x0btotal_pages\x18\x04 \x01(\x05\"\xc4\x01\n\x11ServingLogRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x12\n\nserving_id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12)\n\x05\x61\x66ter\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x62\x65\x66ore\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05limit\x18\x07 \x01(\x05\"3\n\x12ServingLogResponse\x12\x1d\n\x04logs\x18\x02 \x03(\x0b\x32\x0f.lmao_v2.RunLog\"\xef\x02\n\x03Run\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12\x15\n\rexperiment_id\x18\x04 \x01(\t\x12$\n\x05\x61gent\x18\x05 \x01(\x0b\x32\x15.lmao_v2.AgentDetails\x12\x12\n\ncreated_at\x18\x06 \x01(\x03\x12\x12\n\nupdated_at\x18\x07 \x01(\x03\x12\x10\n\x08\x65nded_at\x18\x08 \x01(\x03\x12\x15\n\rsave_location\x18\t \x01(\t\x12\x0e\n\x06\x63onfig\x18\x0b \x01(\t\x12#\n\x06status\x18\x0c \x01(\x0e\x32\x13.lmao_v2.Run.Status\x12\x13\n\x0bupdate_keys\x18\x64 \x03(\t\"J\n\x06Status\x12\x0b\n\x07NOT_SET\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\r\n\tCOMPLETED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0b\n\x07\x44\x45LETED\x10\x04J\x04\x08\n\x10\x0b\"\x8e\x01\n\x0eInitRunRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12,\n\ragent_details\x18\x04 \x01(\x0b\x32\x15.lmao_v2.AgentDetails\x12\x0e\n\x06\x63onfig\x18\x06 \x01(\t\"q\n\x0fListRunsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x15\n\rexperiment_id\x18\x03 \x01(\t\x12\x0f\n\x07page_no\x18\x04 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\x08\"a\n\x10ListRunsResponse\x12\x16\n\x0e\x65xperiment_ids\x18\x01 \x03(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x12\n\ncreated_at\x18\x03 \x03(\x03\x12\x13\n\x0btotal_pages\x18\x04 \x01(\x05\"\x7f\n\rRunLogRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x15\n\rexperiment_id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x10\n\x08start_at\x18\x05 \x01(\x05\x12\x0e\n\x06\x65nd_at\x18\x06 \x01(\x05\"\x89\x01\n\x19GetExperimentTableRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\x12\x15\n\rexperiment_id\x18\x06 \x01(\t\x12\r\n\x05start\x18\x04 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x05 \x01(\x05\"\x95\x01\n\x0f\x45xperimentTable\x12\x13\n\x0btotal_pages\x18\x01 \x01(\x05\x12*\n\x04rows\x18\x02 \x03(\x0b\x32\x1c.lmao_v2.ExperimentTable.Row\x1a\x41\n\x03Row\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12#\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x15.lmao_v2.RecordColumn\"\x8f\x02\n\x04Rule\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x11\n\trule_name\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12\x16\n\x0eis_deactivated\x18\x05 \x01(\x08\x12\x12\n\nis_deleted\x18\x06 \x01(\x08\x12\r\n\x05logic\x18\x07 \x01(\t\x12\x11\n\temail_ids\x18\x08 \x03(\t\x12\x15\n\ralert_message\x18\t \x01(\t\x12\x12\n\ntrue_count\x18\n \x01(\x05\x12\x15\n\rlogic_version\x18\x0b \x01(\x05\x12\x11\n\tmax_range\x18\x0c \x01(\x05\x12\x13\n\x0bupdate_keys\x18\x64 \x03(\t\"\x8c\x01\n\tListRules\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\x12\x13\n\x0btotal_pages\x18\x04 \x01(\x05\x12\x1c\n\x05rules\x18\x05 \x03(\x0b\x32\r.lmao_v2.Rule\x12\x11\n\trule_name\x18\x06 \x01(\t\"\xf9\x01\n\x0bRuleBuilder\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07metrics\x18\x03 \x03(\t\x12*\n\toperators\x18\x04 \x03(\x0b\x32\x17.lmao_v2.RuleBuilder.Op\x12*\n\tfunctions\x18\x05 \x03(\x0b\x32\x17.lmao_v2.RuleBuilder.Fn\x1a\"\n\x02Op\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a\x33\n\x02\x46n\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x66\x65_meta\x18\x03 \x01(\t2\xd2\x0c\n\x04LMAO\x12K\n\x0cinit_project\x12\x1b.lmao_v2.InitProjectRequest\x1a\x1c.lmao_v2.InitProjectResponse\"\x00\x12\x33\n\x0bget_project\x12\x10.lmao_v2.Project\x1a\x10.lmao_v2.Project\"\x00\x12N\n\rlist_projects\x12\x1c.lmao_v2.ListProjectsRequest\x1a\x1d.lmao_v2.ListProjectsResponse\"\x00\x12:\n\x0e\x64\x65lete_project\x12\x10.lmao_v2.Project\x1a\x14.lmao_v2.Acknowledge\"\x00\x12\x33\n\x08init_run\x12\x17.lmao_v2.InitRunRequest\x1a\x0c.lmao_v2.Run\"\x00\x12\x39\n\x11update_run_status\x12\x0c.lmao_v2.Run\x1a\x14.lmao_v2.Acknowledge\"\x00\x12\x31\n\x06on_log\x12\x0f.lmao_v2.RunLog\x1a\x14.lmao_v2.Acknowledge\"\x00\x12\x34\n\x0con_train_end\x12\x0c.lmao_v2.Run\x1a\x14.lmao_v2.Acknowledge\"\x00\x12\x42\n\tlist_runs\x12\x18.lmao_v2.ListRunsRequest\x1a\x19.lmao_v2.ListRunsResponse\"\x00\x12/\n\x0fget_run_details\x12\x0c.lmao_v2.Run\x1a\x0c.lmao_v2.Run\"\x00\x12\x38\n\x0bget_run_log\x12\x16.lmao_v2.RunLogRequest\x1a\x0f.lmao_v2.RunLog\"\x00\x12V\n\x14get_experiment_table\x12\".lmao_v2.GetExperimentTableRequest\x1a\x18.lmao_v2.ExperimentTable\"\x00\x12\x39\n\x11\x64\x65lete_experiment\x12\x0c.lmao_v2.Run\x1a\x14.lmao_v2.Acknowledge\"\x00\x12;\n\x0cinit_serving\x12\x17.lmao_v2.InitRunRequest\x1a\x10.lmao_v2.Serving\"\x00\x12\x41\n\x15update_serving_status\x12\x10.lmao_v2.Serving\x1a\x14.lmao_v2.Acknowledge\"\x00\x12\x39\n\x0eon_serving_log\x12\x0f.lmao_v2.RunLog\x1a\x14.lmao_v2.Acknowledge\"\x00\x12:\n\x0eon_serving_end\x12\x10.lmao_v2.Serving\x1a\x14.lmao_v2.Acknowledge\"\x00\x12N\n\rlist_servings\x12\x1c.lmao_v2.ListServingsRequest\x1a\x1d.lmao_v2.ListServingsResponse\"\x00\x12;\n\x13get_serving_details\x12\x10.lmao_v2.Serving\x1a\x10.lmao_v2.Serving\"\x00\x12L\n\x0fget_serving_log\x12\x1a.lmao_v2.ServingLogRequest\x1a\x1b.lmao_v2.ServingLogResponse\"\x00\x12:\n\x0e\x64\x65lete_serving\x12\x10.lmao_v2.Serving\x1a\x14.lmao_v2.Acknowledge\"\x00\x12@\n\x10get_rule_builder\x12\x14.lmao_v2.RuleBuilder\x1a\x14.lmao_v2.RuleBuilder\"\x00\x12-\n\x0b\x63reate_rule\x12\r.lmao_v2.Rule\x1a\r.lmao_v2.Rule\"\x00\x12\x36\n\nlist_rules\x12\x12.lmao_v2.ListRules\x1a\x12.lmao_v2.ListRules\"\x00\x12\x34\n\x0b\x64\x65lete_rule\x12\r.lmao_v2.Rule\x1a\x14.lmao_v2.Acknowledge\"\x00\x12\x34\n\x0bupdate_rule\x12\r.lmao_v2.Rule\x1a\x14.lmao_v2.Acknowledge\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lmao_v2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJECT._serialized_start=60
  _PROJECT._serialized_end=319
  _INITPROJECTREQUEST._serialized_start=321
  _INITPROJECTREQUEST._serialized_end=363
  _INITPROJECTRESPONSE._serialized_start=365
  _INITPROJECTRESPONSE._serialized_end=466
  _LISTPROJECTSREQUEST._serialized_start=468
  _LISTPROJECTSREQUEST._serialized_end=556
  _LISTPROJECTSRESPONSE._serialized_start=558
  _LISTPROJECTSRESPONSE._serialized_end=637
  _AGENTDETAILS._serialized_start=640
  _AGENTDETAILS._serialized_end=858
  _AGENTDETAILS_NBX._serialized_start=813
  _AGENTDETAILS_NBX._serialized_end=840
  _ACKNOWLEDGE._serialized_start=860
  _ACKNOWLEDGE._serialized_end=907
  _RECORDCOLUMN._serialized_start=910
  _RECORDCOLUMN._serialized_end=1219
  _RECORDCOLUMN_RECORDROW._serialized_start=1039
  _RECORDCOLUMN_RECORDROW._serialized_end=1171
  _RECORDCOLUMN_DATATYPE._serialized_start=1173
  _RECORDCOLUMN_DATATYPE._serialized_end=1219
  _RECORD._serialized_start=1222
  _RECORD._serialized_end=1461
  _RECORD_DATATYPE._serialized_start=1173
  _RECORD_DATATYPE._serialized_end=1219
  _RUNLOG._serialized_start=1464
  _RUNLOG._serialized_end=1717
  _RUNLOG_LOGTYPE._serialized_start=1677
  _RUNLOG_LOGTYPE._serialized_end=1717
  _SERVING._serialized_start=1720
  _SERVING._serialized_end=2071
  _SERVING_STATUS._serialized_start=2009
  _SERVING_STATUS._serialized_end=2071
  _LISTSERVINGSREQUEST._serialized_start=2073
  _LISTSERVINGSREQUEST._serialized_end=2167
  _LISTSERVINGSRESPONSE._serialized_start=2169
  _LISTSERVINGSRESPONSE._serialized_end=2267
  _SERVINGLOGREQUEST._serialized_start=2270
  _SERVINGLOGREQUEST._serialized_end=2466
  _SERVINGLOGRESPONSE._serialized_start=2468
  _SERVINGLOGRESPONSE._serialized_end=2519
  _RUN._serialized_start=2522
  _RUN._serialized_end=2889
  _RUN_STATUS._serialized_start=2809
  _RUN_STATUS._serialized_end=2883
  _INITRUNREQUEST._serialized_start=2892
  _INITRUNREQUEST._serialized_end=3034
  _LISTRUNSREQUEST._serialized_start=3036
  _LISTRUNSREQUEST._serialized_end=3149
  _LISTRUNSRESPONSE._serialized_start=3151
  _LISTRUNSRESPONSE._serialized_end=3248
  _RUNLOGREQUEST._serialized_start=3250
  _RUNLOGREQUEST._serialized_end=3377
  _GETEXPERIMENTTABLEREQUEST._serialized_start=3380
  _GETEXPERIMENTTABLEREQUEST._serialized_end=3517
  _EXPERIMENTTABLE._serialized_start=3520
  _EXPERIMENTTABLE._serialized_end=3669
  _EXPERIMENTTABLE_ROW._serialized_start=3604
  _EXPERIMENTTABLE_ROW._serialized_end=3669
  _RULE._serialized_start=3672
  _RULE._serialized_end=3943
  _LISTRULES._serialized_start=3946
  _LISTRULES._serialized_end=4086
  _RULEBUILDER._serialized_start=4089
  _RULEBUILDER._serialized_end=4338
  _RULEBUILDER_OP._serialized_start=4251
  _RULEBUILDER_OP._serialized_end=4285
  _RULEBUILDER_FN._serialized_start=4287
  _RULEBUILDER_FN._serialized_end=4338
  _LMAO._serialized_start=4341
  _LMAO._serialized_end=5959
# @@protoc_insertion_point(module_scope)
